/*============================================================================
  File:     2b_Track_Queries.sql

  SQL Server Versions: 2008 onwards
------------------------------------------------------------------------------
  Written by Erin Stellato, SQLskills.com
  
  (c) 2013, SQLskills.com. All rights reserved.

  For more scripts and sample code, check out 
    http://www.SQLskills.com

  You may alter this code for your own *non-commercial* purposes. You may
  republish altered code as long as you include this copyright and give due
  credit, but you must obtain prior permission before blogging this code.
  
  THIS CODE AND INFORMATION ARE PROVIDED "AS IS" WITHOUT WARRANTY OF 
  ANY KIND, EITHER EXPRESSED OR IMPLIED, INCLUDING BUT NOT LIMITED 
  TO THE IMPLIED WARRANTIES OF MERCHANTABILITY AND/OR FITNESS FOR A
  PARTICULAR PURPOSE.
============================================================================*/



ALTER EVENT SESSION [Track_Queries]
	ON SERVER
	DROP EVENT sqlserver.sp_statement_completed;
	GO

ALTER EVENT SESSION [Track_Queries]
	ON SERVER
	ADD EVENT sqlserver.sp_statement_completed(SET collect_statement=(1)
		ACTION(
			sqlserver.client_app_name,
			sqlserver.database_id
			)
		WHERE ([package0].[equal_boolean]([sqlserver].[is_system],(0)) AND [object_id]=(1319675749)))
	GO
	

IF EXISTS (SELECT 1 FROM sys.server_event_sessions WHERE name = 'Track_Queries')
	DROP EVENT SESSION [Track_Queries] ON SERVER;
GO

CREATE EVENT SESSION [Track_Queries] 
	ON SERVER 
	ADD EVENT sqlserver.sp_statement_completed(SET collect_statement=(1)
		ACTION(
			sqlserver.client_app_name,
			sqlserver.database_id
			)
		WHERE ([package0].[equal_boolean]([sqlserver].[is_system],(0)) AND [object_id]=(1319675749)))
ADD TARGET package0.event_file(SET filename=N'C:\Temp\XEvents\Track_Queries.xel'),
ADD TARGET package0.ring_buffer(SET max_events_limit=(10000),max_memory=(2048))
WITH (MAX_MEMORY=4096 KB,EVENT_RETENTION_MODE=ALLOW_SINGLE_EVENT_LOSS,MAX_DISPATCH_LATENCY=30 SECONDS,MAX_EVENT_SIZE=0 KB,MEMORY_PARTITION_MODE=NONE,TRACK_CAUSALITY=OFF,STARTUP_STATE=OFF)
GO



ALTER EVENT SESSION [Track_Queries]
	ON SERVER
	STATE=START;
	GO

--run .ps1 scripts

ALTER EVENT SESSION [Track_Queries]
	ON SERVER
	DROP EVENT sqlserver.sp_statement_completed;
	GO

-- Create XML variable to hold Target Data
DECLARE @target_data XML;
SELECT @target_data = CAST(target_data AS XML)
FROM sys.dm_xe_sessions AS s 
JOIN sys.dm_xe_session_targets AS t 
    ON t.event_session_address = s.address
WHERE s.name = N'Track_Queries'
  AND t.target_name = N'ring_buffer';

-- Query XML variable to get Event Data
SELECT 
    @target_data.value('(RingBufferTarget/@eventsPerSec)[1]', 'int') AS eventsPerSec,
    @target_data.value('(RingBufferTarget/@processingTime)[1]', 'int') AS processingTime,
    @target_data.value('(RingBufferTarget/@totalEventsProcessed)[1]', 'int') AS totalEventsProcessed,
    @target_data.value('(RingBufferTarget/@eventCount)[1]', 'int') AS eventCount,
    @target_data.value('(RingBufferTarget/@droppedCount)[1]', 'int') AS droppedCount,
    @target_data.value('(RingBufferTarget/@memoryUsed)[1]', 'int') AS memoryUsed;

SELECT 
    n.value('(@name)[1]', 'varchar(50)') AS [event_name],
    --n.value('(@package)[1]', 'varchar(50)') AS [package_name],
    DATEADD(hh, 
            DATEDIFF(hh, GETUTCDATE(), CURRENT_TIMESTAMP), 
            n.value('(@timestamp)[1]', 'datetime2')) AS [timestamp],
    n.value('(data[@name="session_id"]/value)[1]', 'int') AS [session_id],
	n.value('(data[@name="duration"]/value)[1]', 'int') AS [duration],
    n.value('(data[@name="logical_reads"]/value)[1]', 'int') AS [logicalreads],
    n.value('(data[@name="statement"]/value)[1]', 'nvarchar(max)') AS [statement]
FROM @target_data.nodes('RingBufferTarget/event') AS q(n);
GO



ALTER EVENT SESSION [Track_Queries]
	ON SERVER
	STATE=STOP;
	GO
	
DROP EVENT SESSION [Track_Queries]
	ON SERVER;
	GO
    